@@ -1,9 +1,7 @@
 package Email::MIME::Kit::Bulk;
-BEGIN {
-  $Email::MIME::Kit::Bulk::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Email::MIME::Kit-based bulk mailer
-$Email::MIME::Kit::Bulk::VERSION = '0.0.2';
+$Email::MIME::Kit::Bulk::VERSION = '0.0.3';
 
 use Moose;
 use namespace::autoclean;
@@ -234,7 +232,7 @@ Email::MIME::Kit::Bulk - Email::MIME::Kit-based bulk mailer
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 SYNOPSIS
 
@@ -375,7 +373,7 @@ Yanick Champoux <yanick.champoux@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive <contact@iinteractive.com>.
+This software is copyright (c) 2017 by Infinity Interactive <contact@iinteractive.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
