@@ -1,9 +1,7 @@
 package Email::MIME::Kit::Bulk::Command;
-BEGIN {
-  $Email::MIME::Kit::Bulk::Command::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: send bulk emails using Email::MIME::Kit
-$Email::MIME::Kit::Bulk::Command::VERSION = '0.0.2';
+$Email::MIME::Kit::Bulk::Command::VERSION = '0.0.3';
 
 use strict;
 use warnings;
@@ -102,7 +100,7 @@ Email::MIME::Kit::Bulk::Command - send bulk emails using Email::MIME::Kit
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 SYNOPSIS
 
@@ -126,7 +124,7 @@ Yanick Champoux <yanick.champoux@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive <contact@iinteractive.com>.
+This software is copyright (c) 2017 by Infinity Interactive <contact@iinteractive.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
