@@ -1,9 +1,7 @@
 package Email::MIME::Kit::Bulk::Kit;
-BEGIN {
-  $Email::MIME::Kit::Bulk::Kit::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Email::MIME kit customized for Email::MIME::Kit::Bulk
-$Email::MIME::Kit::Bulk::Kit::VERSION = '0.0.2';
+$Email::MIME::Kit::Bulk::Kit::VERSION = '0.0.3';
 
 use strict;
 use warnings;
@@ -14,7 +12,7 @@ use Moose;
 
 extends 'Email::MIME::Kit';
 
-has '+manifest_reader' => (
+has '+_manifest_reader_seed' => (
     default => '=Email::MIME::Kit::Bulk::ManifestReader::JSON',
 );
 
@@ -41,7 +39,7 @@ Email::MIME::Kit::Bulk::Kit - Email::MIME kit customized for Email::MIME::Kit::B
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 DESCRIPTION
 
@@ -65,7 +63,7 @@ Yanick Champoux <yanick.champoux@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive <contact@iinteractive.com>.
+This software is copyright (c) 2017 by Infinity Interactive <contact@iinteractive.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
