@@ -1,9 +1,7 @@
 package Email::MIME::Kit::Bulk::ManifestReader::JSON;
-BEGIN {
-  $Email::MIME::Kit::Bulk::ManifestReader::JSON::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Extension of E::M::K::ManifestReader::JSON for Email::MIME::Kit::Bulk
-$Email::MIME::Kit::Bulk::ManifestReader::JSON::VERSION = '0.0.2';
+$Email::MIME::Kit::Bulk::ManifestReader::JSON::VERSION = '0.0.3';
 
 use Moose;
 
@@ -39,7 +37,7 @@ Email::MIME::Kit::Bulk::ManifestReader::JSON - Extension of E::M::K::ManifestRea
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 DESCRIPTION
 
@@ -64,7 +62,7 @@ Yanick Champoux <yanick.champoux@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive <contact@iinteractive.com>.
+This software is copyright (c) 2017 by Infinity Interactive <contact@iinteractive.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
