@@ -1,9 +1,7 @@
 package Email::MIME::Kit::Bulk::Target;
-BEGIN {
-  $Email::MIME::Kit::Bulk::Target::AUTHORITY = 'cpan:YANICK';
-}
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Destination for an Email::MIME::Kit::Bulk email
-$Email::MIME::Kit::Bulk::Target::VERSION = '0.0.2';
+$Email::MIME::Kit::Bulk::Target::VERSION = '0.0.3';
 
 use strict;
 use warnings;
@@ -98,7 +96,7 @@ Email::MIME::Kit::Bulk::Target - Destination for an Email::MIME::Kit::Bulk email
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 SYNOPSIS
 
@@ -239,7 +237,7 @@ Yanick Champoux <yanick.champoux@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Infinity Interactive <contact@iinteractive.com>.
+This software is copyright (c) 2017 by Infinity Interactive <contact@iinteractive.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
